@@ -1,11 +1,11 @@
-#include "xslt_kde.h"
+#include "docbookxslt.h"
 #ifndef MEINPROC_NO_KARCHIVE
-#include <kfilterdev.h>
+#include <KFilterDev>
 #else
-#include <QDebug>
+#include "loggingcategory.h"
 #endif
 
-bool saveToCache(const QString &contents, const QString &filename)
+bool KDocTools::saveToCache(const QString &contents, const QString &filename)
 {
 #ifndef MEINPROC_NO_KARCHIVE
     KFilterDev fd(filename);
@@ -17,7 +17,7 @@ bool saveToCache(const QString &contents, const QString &filename)
     fd.write(contents.toUtf8());
     fd.close();
 #else
-    qWarning() << "This function is dummy because KArchive support has been disabled. "
+    qCWarning(KDocToolsLog) << "This function is dummy because KArchive support has been disabled. "
                "This mode should be enabled only for specific usage on KDE infrastructure.";
     Q_UNUSED(contents)
     Q_UNUSED(filename)
